
.. blogpost::
    :title: A website with Tornado
    :keywords: reference, blog, post
    :date: 2017-10-16
    :categories: C#, DLL

    Implements a light website with :epkg:`tornado`
    to hold leaderboard for a competition.
